pub struct FenceToken(pub u64);Expand description
Monotonic fencing token (FR-7c). Bumped every time this node assumes
the singleton, so stale writers from a prior incarnation can be
rejected by comparing tokens. Ord so the highest token wins.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for FenceToken
impl Clone for FenceToken
Sourcefn clone(&self) -> FenceToken
fn clone(&self) -> FenceToken
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FenceToken
impl Debug for FenceToken
Sourceimpl Hash for FenceToken
impl Hash for FenceToken
Sourceimpl Ord for FenceToken
impl Ord for FenceToken
Sourcefn cmp(&self, other: &FenceToken) -> Ordering
fn cmp(&self, other: &FenceToken) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FenceToken
impl PartialEq for FenceToken
Sourcefn eq(&self, other: &FenceToken) -> bool
fn eq(&self, other: &FenceToken) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FenceToken
impl PartialOrd for FenceToken
impl Copy for FenceToken
impl Eq for FenceToken
impl StructuralPartialEq for FenceToken